@@ -10,7 +10,7 @@ use Lemonldap::NG::Portal::Main::Constants qw(
   PE_OK
 );
 
-our $VERSION = '2.0.12';
+our $VERSION = '2.22.0';
 
 extends 'Lemonldap::NG::Portal::Main::Auth';
 
@@ -53,7 +53,7 @@ sub auth_route {
     }
     else {
         $req->wantErrorRender(1);
-        return $self->p->do( $req, [ sub { PE_CERTIFICATEREQUIRED } ] );
+        return $self->p->doPE($req, PE_CERTIFICATEREQUIRED);
     }
 }
 
@@ -127,22 +127,13 @@ sub extractFormInfo {
             return PE_CERTIFICATEREQUIRED;
         }
 
-        $self->logger->debug( 'Append ' . $self->{Name} . ' init/script' );
-        $req->data->{customScript} .= $self->{AjaxInitScript};
-        $self->logger->debug(
-            "Send init/script -> " . $req->data->{customScript} );
+        $self->initDisplay($req);
         $req->data->{waitingMessage} = 1;
-
-        eval( $self->InitCmd );
-        die 'Unable to launch init commmand ' . $self->{InitCmd} if ($@);
         return PE_FIRSTACCESS;
     }
     else {
         if ( $self->conf->{sslByAjax} ) {
-            $self->logger->debug( 'Append ' . $self->{Name} . ' init/script' );
-            $req->data->{customScript} .= $self->{AjaxInitScript};
-            $self->logger->debug(
-                "Send init/script -> " . $req->data->{customScript} );
+            $self->initDisplay($req);
             return PE_BADCERTIFICATE;
         }
         $self->userLogger->warn('No certificate found');
