@@ -86,6 +86,54 @@ eQIDAQAB
 -----END PUBLIC KEY-----";
 }
 
+sub saml_key_proxy_cert_enc {
+    "-----BEGIN CERTIFICATE-----
+MIIDbTCCAlWgAwIBAgIUHhmuu1i4Oodctizp3ivZwdPADtEwDQYJKoZIhvcNAQEL
+BQAwRTELMAkGA1UEBhMCQVUxEzARBgNVBAgMClNvbWUtU3RhdGUxITAfBgNVBAoM
+GEludGVybmV0IFdpZGdpdHMgUHR5IEx0ZDAgFw0yNTA5MDkwODEwNTJaGA8yMTI1
+MDgxNjA4MTA1MlowRTELMAkGA1UEBhMCQVUxEzARBgNVBAgMClNvbWUtU3RhdGUx
+ITAfBgNVBAoMGEludGVybmV0IFdpZGdpdHMgUHR5IEx0ZDCCASIwDQYJKoZIhvcN
+AQEBBQADggEPADCCAQoCggEBANr86FIkOBrDOai46MbJRAyo/kaz4fwO+NyQlntR
+22nY3ecg+ID8JiVMTBfjCXEJaP05Jim06Jz3SKAKg5J21MXxU57adFZHSqweuMa9
+Eracu9dt4T7M2rd0m1N0WMqXaGxHLkgEu+8PV9Sp5ES9fgiHufakrIITt5d29iCe
+qjxV3cf3K6O/itzu8PMABCfSpsQNCnYmaUhYEwKnzQ0isfDS8GTng6bB6LgMctRN
+pIp3vvREgU0QDNj4Ihmb1OSQNUmbHHRIN8E37SccTxZwCTMLajNyFQugfk6rCD+V
+pZNT0EKh++YI7QWA1XbspwcFPpf1FJqdWg0Wbqbh/DxedacCAwEAAaNTMFEwHQYD
+VR0OBBYEFLW/evNijEugkS2kqexwN2Ydp0LMMB8GA1UdIwQYMBaAFLW/evNijEug
+kS2kqexwN2Ydp0LMMA8GA1UdEwEB/wQFMAMBAf8wDQYJKoZIhvcNAQELBQADggEB
+AKIMOBJ/uplUIDArX6UygIdpFa+I/T9earwx6fLYVH1vM/fWJTPiijL5s+a/eftf
+MJ8hy/Ac3UTZg63X10mPeLMjnWv/nLsttp6fifBz86g+xFx8FZHRt6KxrWC45PwE
+XaYbm9r79kjRtKfTzO05I6VOQaip5+3qGMPc9JCfJ+sxnRNl9E3kiNA1Sitzs6Mp
+Y2R0kEvyHCEJa0j5nFuyZpCD3kau1pxsNa44QuGW0egjO61ri96Bn72xAUtDuozw
+ikVPX5/wIyC9oMXdUyJXN7incU0n6cIiza70X7wlgehRkSsbrHUWGUs5/ASShOo0
+t1Grxc3Vfbw3Fqir6wn46OE=
+-----END CERTIFICATE-----";
+}
+
+sub saml_key_proxy_cert_sig {
+    "-----BEGIN CERTIFICATE-----
+MIIDbTCCAlWgAwIBAgIUFscP0cOkJ/U2YuZkgeHTxh0o4BgwDQYJKoZIhvcNAQEL
+BQAwRTELMAkGA1UEBhMCQVUxEzARBgNVBAgMClNvbWUtU3RhdGUxITAfBgNVBAoM
+GEludGVybmV0IFdpZGdpdHMgUHR5IEx0ZDAgFw0yNTA4MDExNDAyMjJaGA8yMTI1
+MDcwODE0MDIyMlowRTELMAkGA1UEBhMCQVUxEzARBgNVBAgMClNvbWUtU3RhdGUx
+ITAfBgNVBAoMGEludGVybmV0IFdpZGdpdHMgUHR5IEx0ZDCCASIwDQYJKoZIhvcN
+AQEBBQADggEPADCCAQoCggEBAM7Zm9SWZP2oJGGJttw+Hami0uBChyq4zuHgb8LV
+mS3sQBkdSg6XKx6i8qiaGpfquAPHayO5cRJUresUSieAyMUDNY6kXJhOhM3S+gX0
+2kWnHt8yLoYw0kFGSXbRbZScp0E9XCW8eWWIamW2ADZvTWUXGGeYFnshfZ5eNcQO
+/QDLmJabe3lg0fHJ0CV8Fe/dPfdRUPcgNgQYE3UipBame9j+JVruLIc9yQhn+Ycq
+tN4Qh0O27H6YAHQq20D07iTRbUuffQpTLvgHEXMCXEtt96R3d9Oj0Rwl59xGqauo
+BKB8YC1TafpbgCIUQPRGjp2dJ1ZBcBSp97y181dNYk5YjHkCAwEAAaNTMFEwHQYD
+VR0OBBYEFA4wi6itTPYB2iQ3nSCAys3qp8iZMB8GA1UdIwQYMBaAFA4wi6itTPYB
+2iQ3nSCAys3qp8iZMA8GA1UdEwEB/wQFMAMBAf8wDQYJKoZIhvcNAQELBQADggEB
+AKzSKAeAq5/9iypK67rJbEidZjoID9v8IgyzmOmrCG4dwJhmmN7ZdJuwFE50x9id
+mdTCJMJg4ZMKAcFDEHGNKi/YIDQglnF8E3fG5sJ7nGJc44fAlkpp01LSsjYLRB+j
+X3ax2PDbYRc/qnkrMVXcqj19PYY/cBCn2epyWuG7Za6RuLXT35aEkvrnmZpvfBgl
+drcvJIwl29yZRpjNp3xLTdc5F1tF3OD2i5TQiYmdMpM4qSZ2Tz4IT3PKs45ZtjdS
+lWJX7ivL+rq+TbiY680PL69IyTxWphBy9YYmGHVUTZJUxMMSKiI7CpDPQQ13F1wX
+FnQH+J3thbkj8O6gqWZ5X3E=
+-----END CERTIFICATE-----";
+}
+
 sub saml_key_idp_private_enc {
     "-----BEGIN RSA PRIVATE KEY-----
 MIIEogIBAAKCAQEAnfKBDG/K0TnGT7Xu8q1N45sNWvIK91SqNg8nvN2uVeKoHADT
@@ -170,16 +218,52 @@ ywIDAQAB
 -----END PUBLIC KEY----- ";
 }
 
-sub saml_key_sp_public_sig {
-    "-----BEGIN PUBLIC KEY-----
-MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAu4iToYAEmWQxgZDihGVz
-MMql1elPn37domWcvXeU2E4yt2hh5jkQHiFjgodfOlNeRIw5QJVlUBwr+CQvbaKR
-FXd7BrOhQIDC0TZPRVB0XHarUtsCuDekN4/2GKSzHsoToKUVPWq9thsuek3xkpsJ
-GZNX7bglfEc9+QQpYTqN1rkdN1PVU0epNMokFFGho5pLRqLUV5+I/QXAL49jfTja
-Sxsp4UndTI8/+mGSRSq+nrT2zyQRM/vkj5vR9ZVz67HO/+Wk3Mx6RAwkVcMdgMAq
-Cq8odmbI0yCRZiTL9ybKWRKqWJoKJ0p5+Q2fPEBPupQZR09Jt/JPuLVSsGfCxi9N
-qwIDAQAB
------END PUBLIC KEY----- ";
+sub saml_key_idp_cert_enc {
+    "-----BEGIN CERTIFICATE-----
+MIIDbTCCAlWgAwIBAgIUKagKPBppVRRYwcgzg5xGHPQBO8wwDQYJKoZIhvcNAQEL
+BQAwRTELMAkGA1UEBhMCQVUxEzARBgNVBAgMClNvbWUtU3RhdGUxITAfBgNVBAoM
+GEludGVybmV0IFdpZGdpdHMgUHR5IEx0ZDAgFw0yNTA5MDkwODExMTJaGA8yMTI1
+MDgxNjA4MTExMlowRTELMAkGA1UEBhMCQVUxEzARBgNVBAgMClNvbWUtU3RhdGUx
+ITAfBgNVBAoMGEludGVybmV0IFdpZGdpdHMgUHR5IEx0ZDCCASIwDQYJKoZIhvcN
+AQEBBQADggEPADCCAQoCggEBAJ3ygQxvytE5xk+17vKtTeObDVryCvdUqjYPJ7zd
+rlXiqBwA03LLrOV594nefvEPU7jBbFvZCBHl4mjyl0Gva8n0jQ4Vg1paDZKRhHlo
+n9gZx1LuOgG7tVAVm9Jh+lcHBtT0eKh67i4rNaHY0Nap1QzX0hAElSKaRAWIw19t
+N8qZlESM1OoedxkUUZX9QS1pG1Z/crJg3kee18OUbMf/rQZXJzK5L/+NA0lJHoUC
+JdiZpRa5dgmopPoFOKXdtGqQP6TS4wWRdDphqEtPACEeTTHdChWugsGVFEhyah+R
+hcuWNspeJYPCtJJQEvauy+2lyPnhUGYZMInY6cV5xz8sSBkCAwEAAaNTMFEwHQYD
+VR0OBBYEFDoYeBGs9qjH9DWBjWuLZlpgxUHzMB8GA1UdIwQYMBaAFDoYeBGs9qjH
+9DWBjWuLZlpgxUHzMA8GA1UdEwEB/wQFMAMBAf8wDQYJKoZIhvcNAQELBQADggEB
+AHmwxWBvgwHsbgjByiAvlMc71AGe3KtBPomddEwbR0a4F/YHBh03MSIbkRzyy+N5
+9bYPzkE0eDk8CH6S19gWJLYlauVjWuPwD5qfn2pk4B0Pxm+PGSCdcXCp9gfX2H1G
+wV7db5yF5esm9sT8h26tCsF1pES0gqsgM+/7BZWYfMt7KRrBdtP/J8rdw3UrpIMD
+5+KZOxj/2b/OZkeK9xXsNJcXnAS2XxVOghXsGFrK7I7RQZad0mpHTNOywORb8D0y
+RMr5jii8f2/FhAG6YA5c8Bmxd0Hu8vEtR8psf5HEt4jMlzawVfVBS3V4RKdrPMvb
+7AA0s1Lbzan5JuWwi3Z7tC0=
+-----END CERTIFICATE-----";
+}
+
+sub saml_key_idp_cert_sig {
+    "-----BEGIN CERTIFICATE-----
+MIIDbTCCAlWgAwIBAgIUXsAX6Z/sTIq+w08CtE4HRuEdf2EwDQYJKoZIhvcNAQEL
+BQAwRTELMAkGA1UEBhMCQVUxEzARBgNVBAgMClNvbWUtU3RhdGUxITAfBgNVBAoM
+GEludGVybmV0IFdpZGdpdHMgUHR5IEx0ZDAgFw0yNTA4MDExNDAzMzVaGA8yMTI1
+MDcwODE0MDMzNVowRTELMAkGA1UEBhMCQVUxEzARBgNVBAgMClNvbWUtU3RhdGUx
+ITAfBgNVBAoMGEludGVybmV0IFdpZGdpdHMgUHR5IEx0ZDCCASIwDQYJKoZIhvcN
+AQEBBQADggEPADCCAQoCggEBALUf8IA6lgeDGoaOVek43C/zWzX44CIexnIJKweU
+WXFU9Rk3oyZTI1EHYASgbmV0Dfu/9vT+lHBqtZGGpVEaukvEqXidaH6eawRKA/0y
+JL1NCTnIneucKfn3c1xl7H4mbx62lO+I0goIz/8Kn1RkcgSEMwdEiMUqZ67IoKjb
+BNRPeLaAzMeMKL4x7v/QAQCJkRFe0s/NznhRdNP7IIa40xCTg/4B39OCQp/TIDTq
+r0k8rK/S11oP6FCkAxGHk6vbseqav6Kr9TMcDjW0mT7Tecg+NZovoU/EYflvCXvK
+7IjC+FTMc7G9Zfd9N2rMOrLqOWy0yEijUm7tZ7dTZKTcc8sCAwEAAaNTMFEwHQYD
+VR0OBBYEFNBDjE4qyY/dQTYHuG83e+nfiyXyMB8GA1UdIwQYMBaAFNBDjE4qyY/d
+QTYHuG83e+nfiyXyMA8GA1UdEwEB/wQFMAMBAf8wDQYJKoZIhvcNAQELBQADggEB
+AD25y0JCSM42jZkkikqxL1alyW7KRm8llH3iw9uo9YqoUFZJCbF4dyVbjzTOGVIH
+1d/felt2q5Ntcl+VtccODIjg2GpM6QteY4hq0mFy2Kwp8drR4HPryFOfhkxruPD4
+Pp4BI9HbFZouc9lpEPxsfiWrqbpKSrPFsxCnq2gfz7LiM4K7/chXl1nvBsk2jfpp
+qHx6YO+btmJX4VQnkYaAMENA93FtXZASqt3dNI7GuqOi/7NmUAEDx+Gh2XF6WB3Q
+7ZugYlhGdFm/idQidpf5zNwNk2WMQ8RBlROKecgqEfUhpLeDziOek4cbsWbG2voz
+yf+fBOtOrWK7VpWeIkMLJZY=
+-----END CERTIFICATE-----";
 }
 
 sub saml_key_sp_private_enc {
@@ -254,6 +338,66 @@ XVhuG8OrWQDoS5gYHSjdw1CTJyixeJwyoqA9RGYguG5nh9zndi3LWAh7Z0lx+tIz
 -----END PUBLIC KEY-----";
 }
 
+sub saml_key_sp_public_sig {
+    "-----BEGIN PUBLIC KEY-----
+MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAu4iToYAEmWQxgZDihGVz
+MMql1elPn37domWcvXeU2E4yt2hh5jkQHiFjgodfOlNeRIw5QJVlUBwr+CQvbaKR
+FXd7BrOhQIDC0TZPRVB0XHarUtsCuDekN4/2GKSzHsoToKUVPWq9thsuek3xkpsJ
+GZNX7bglfEc9+QQpYTqN1rkdN1PVU0epNMokFFGho5pLRqLUV5+I/QXAL49jfTja
+Sxsp4UndTI8/+mGSRSq+nrT2zyQRM/vkj5vR9ZVz67HO/+Wk3Mx6RAwkVcMdgMAq
+Cq8odmbI0yCRZiTL9ybKWRKqWJoKJ0p5+Q2fPEBPupQZR09Jt/JPuLVSsGfCxi9N
+qwIDAQAB
+-----END PUBLIC KEY----- ";
+}
+
+sub saml_key_sp_cert_enc {
+    "-----BEGIN CERTIFICATE-----
+MIIDbTCCAlWgAwIBAgIUOA3efx8MRvHM5iY9EGO12QF4iJQwDQYJKoZIhvcNAQEL
+BQAwRTELMAkGA1UEBhMCQVUxEzARBgNVBAgMClNvbWUtU3RhdGUxITAfBgNVBAoM
+GEludGVybmV0IFdpZGdpdHMgUHR5IEx0ZDAgFw0yNTA5MDkwODExMDFaGA8yMTI1
+MDgxNjA4MTEwMVowRTELMAkGA1UEBhMCQVUxEzARBgNVBAgMClNvbWUtU3RhdGUx
+ITAfBgNVBAoMGEludGVybmV0IFdpZGdpdHMgUHR5IEx0ZDCCASIwDQYJKoZIhvcN
+AQEBBQADggEPADCCAQoCggEBALEWqHdkWfITBQZflYbJ4cjzPJfxY9aG5wcX0CGl
+rhxSBX14hnvwmB7meUCUC52cRzCV+iy90oflLKIN6dI6Yo6XINEIHwUhJH6KSk4E
+XmDfA4gyJZdK1dV3U54uxPOTXdWMjct7ov2Q/lEoVsKruoy1S0fkFJvv9SyCmG9z
+ggU7zpWO8R6D+jUlNfjK/mMxgVGnHTtr5zcXvz0IcSHj9cztJ47qhh5MBKcvK1Fk
+WW2w599U5io6pYYLbM+Rz4W0WmBBMYcnqSoAYjc/kcsbWF1YbhvDq1kA6EuYGB0o
+3cNQkycosXicMqKgPURmILhuZ4fc53Yty1gIe2dJcfrSM/sCAwEAAaNTMFEwHQYD
+VR0OBBYEFCp9viKGGM4+UmvTcd9myvQ/x4w4MB8GA1UdIwQYMBaAFCp9viKGGM4+
+UmvTcd9myvQ/x4w4MA8GA1UdEwEB/wQFMAMBAf8wDQYJKoZIhvcNAQELBQADggEB
+AHaOJ8ssJjLG9z3eGEmqXSpUPRyKLxt7g+SGYziTgRvLmmLxltxFU0SNaHN6a/ax
+3T08c1t2T28XK0kqYxEVR7xWAA8Y96GwXB2D12NDOpR96LT1eN33GpjZZLB6NvuI
+cgfaDvr/Sl08V2aoamJKyS28FtUvCOELPE7qcwIYw3oL8Rp6uZUpho+SUzgcoNd5
+JYUPWyWo4MVj8hDy3Ebo7YjZhkYZPaV1gA0BTOfZWi/0E/Okr/XQkxaaRihc16xF
+68fPmPSEy7xRvjDuUOu7WAOxUR+axcLzuZhHIQCSxwyMBG7zXXre6X/AzQnQ14qe
+jVPqpsCFhz+xUGJV7WSwfMQ=
+-----END CERTIFICATE-----";
+}
+
+sub saml_key_sp_cert_sig {
+    "-----BEGIN CERTIFICATE-----
+MIIDbTCCAlWgAwIBAgIUXDHeTxgAdIpOp2++gWrRaBr9CxwwDQYJKoZIhvcNAQEL
+BQAwRTELMAkGA1UEBhMCQVUxEzARBgNVBAgMClNvbWUtU3RhdGUxITAfBgNVBAoM
+GEludGVybmV0IFdpZGdpdHMgUHR5IEx0ZDAgFw0yNTA4MDExNDA0NDFaGA8yMTI1
+MDcwODE0MDQ0MVowRTELMAkGA1UEBhMCQVUxEzARBgNVBAgMClNvbWUtU3RhdGUx
+ITAfBgNVBAoMGEludGVybmV0IFdpZGdpdHMgUHR5IEx0ZDCCASIwDQYJKoZIhvcN
+AQEBBQADggEPADCCAQoCggEBALuIk6GABJlkMYGQ4oRlczDKpdXpT59+3aJlnL13
+lNhOMrdoYeY5EB4hY4KHXzpTXkSMOUCVZVAcK/gkL22ikRV3ewazoUCAwtE2T0VQ
+dFx2q1LbArg3pDeP9hiksx7KE6ClFT1qvbYbLnpN8ZKbCRmTV+24JXxHPfkEKWE6
+jda5HTdT1VNHqTTKJBRRoaOaS0ai1FefiP0FwC+PY3042ksbKeFJ3UyPP/phkkUq
+vp609s8kETP75I+b0fWVc+uxzv/lpNzMekQMJFXDHYDAKgqvKHZmyNMgkWYky/cm
+ylkSqliaCidKefkNnzxAT7qUGUdPSbfyT7i1UrBnwsYvTasCAwEAAaNTMFEwHQYD
+VR0OBBYEFEWmfbeUIDfMp28Nm5ZoYCBww1NnMB8GA1UdIwQYMBaAFEWmfbeUIDfM
+p28Nm5ZoYCBww1NnMA8GA1UdEwEB/wQFMAMBAf8wDQYJKoZIhvcNAQELBQADggEB
+ALA5okXVSvdIb0GtYhon2d22X5Hpd16n3UHxFcEfRClz/fR1t42BjJeVsjoB9gdq
+ded8X3Wx5Ufmx+IcP5MkItA4X3poctULnScyraL8Bjyiry2mmMwssS7dxfKtq0kb
+Cjkt9aKdVg/K4IpjfAL2yWN7dLhyKC8iFQTGZQLEYSoWllU6O0mY1G3yESnd3ZhM
+pm6Hj4As5CxdlhRC3wFe0WSsXctXZXnig5Vu8aXvuJdGCmeimLmmVUN6XoKs04km
+GpOaw66yU3Q2Bkj0Q32V6eoXHxeMmJzRFjlAlFX8ouaTXIJlla1zQ6EEVhhHyIJx
+qkDlp/EbsA5pW9bJpalb0hA=
+-----END CERTIFICATE-----";
+}
+
 sub samlSPMetaDataXML {
     my ( $name, $type ) = @_;
     my $org = uc($name);
@@ -302,18 +446,12 @@ entityID="http://auth.$name.com/saml/metadata">
     <SingleLogoutService Binding="urn:oasis:names:tc:SAML:2.0:bindings:$type"
      Location="http://auth.$name.com/saml/singleLogout"
     ResponseLocation="http://auth.$name.com/saml/singleLogoutReturn" />
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
     <SingleSignOnService Binding="urn:oasis:names:tc:SAML:2.0:bindings:$type"
      Location="http://auth.$name.com/saml/singleSignOn" />
   </IDPSSODescriptor>
@@ -357,18 +495,12 @@ entityID="http://auth.$name.com/saml/metadata">
     <SingleLogoutService Binding="urn:oasis:names:tc:SAML:2.0:bindings:$type"
      Location="http://auth.$name.com/saml/proxySingleLogout"
     ResponseLocation="http://auth.$name.com/saml/proxySingleLogoutReturn" />
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
     <AssertionConsumerService isDefault="true" index="0"
      Binding="urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST"
      Location="http://auth.$name.com/saml/proxySingleSignOnPost" />
@@ -413,18 +545,12 @@ entityID="http://auth.$name.com/saml/metadata">
     </KeyDescriptor>
     <AttributeService Binding="urn:oasis:names:tc:SAML:2.0:bindings:SOAP"
      Location="http://auth.$name.com/saml/AA/SOAP" />
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
   </AttributeAuthorityDescriptor>
   <Organization>
     <OrganizationName xml:lang="en">$org</OrganizationName>
@@ -486,18 +612,12 @@ entityID="http://auth.$name.com/saml/metadata">
     <SingleLogoutService Binding="urn:oasis:names:tc:SAML:2.0:bindings:$typeSLO"
      Location="http://auth.$name.com/saml/singleLogout"
     ResponseLocation="http://auth.$name.com/saml/singleLogoutReturn" />
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
     <SingleSignOnService Binding="urn:oasis:names:tc:SAML:2.0:bindings:$typeSSO"
      Location="http://auth.$name.com/saml/singleSignOn" />
   </IDPSSODescriptor>
@@ -541,18 +661,12 @@ entityID="http://auth.$name.com/saml/metadata">
     <SingleLogoutService Binding="urn:oasis:names:tc:SAML:2.0:bindings:$typeSLO"
      Location="http://auth.$name.com/saml/proxySingleLogout"
     ResponseLocation="http://auth.$name.com/saml/proxySingleLogoutReturn" />
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
     <AssertionConsumerService isDefault="true" index="0"
      Binding="urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST"
      Location="http://auth.$name.com/saml/proxySingleSignOnPost" />
@@ -597,18 +711,12 @@ entityID="http://auth.$name.com/saml/metadata">
     </KeyDescriptor>
     <AttributeService Binding="urn:oasis:names:tc:SAML:2.0:bindings:SOAP"
      Location="http://auth.$name.com/saml/AA/SOAP" />
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
   </AttributeAuthorityDescriptor>
   <Organization>
     <OrganizationName xml:lang="en">$org</OrganizationName>
@@ -671,18 +779,12 @@ oAqDknbUxfFTntp0VkdKrB64xr0Stpy7123hPszat3SbU3RYypdobEcuSAS77w9X1KnkRL1+CIe5
     <SingleLogoutService Binding="urn:oasis:names:tc:SAML:2.0:bindings:$type"
      Location="http://auth.$name.com/saml/singleLogout"
     ResponseLocation="http://auth.$name.com/saml/singleLogoutReturn" />
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
     <SingleSignOnService Binding="urn:oasis:names:tc:SAML:2.0:bindings:$type"
      Location="http://auth.$name.com/saml/singleSignOn" />
   </IDPSSODescriptor>
@@ -728,18 +830,12 @@ oAqDknbUxfFTntp0VkdKrB64xr0Stpy7123hPszat3SbU3RYypdobEcuSAS77w9X1KnkRL1+CIe5
     <SingleLogoutService Binding="urn:oasis:names:tc:SAML:2.0:bindings:$type"
      Location="http://auth.$name.com/saml/proxySingleLogout"
     ResponseLocation="http://auth.$name.com/saml/proxySingleLogoutReturn" />
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
     <AssertionConsumerService isDefault="true" index="0"
      Binding="urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST"
      Location="http://auth.$name.com/saml/proxySingleSignOnPost" />
@@ -783,18 +879,12 @@ oAqDknbUxfFTntp0VkdKrB64xr0Stpy7123hPszat3SbU3RYypdobEcuSAS77w9X1KnkRL1+CIe5
     </KeyDescriptor>
     <AttributeService Binding="urn:oasis:names:tc:SAML:2.0:bindings:SOAP"
      Location="http://auth.$name.com/saml/AA/SOAP" />
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
   </AttributeAuthorityDescriptor>
   <Organization>
     <OrganizationName xml:lang="en">$org</OrganizationName>
@@ -857,18 +947,12 @@ oAqDknbUxfFTntp0VkdKrB64xr0Stpy7123hPszat3SbU3RYypdobEcuSAS77w9X1KnkRL1+CIe5
     <SingleLogoutService Binding="urn:oasis:names:tc:SAML:2.0:bindings:$typeSLO"
      Location="http://auth.$name.com/saml/singleLogout"
     ResponseLocation="http://auth.$name.com/saml/singleLogoutReturn" />
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
     <SingleSignOnService Binding="urn:oasis:names:tc:SAML:2.0:bindings:$typeSSO"
      Location="http://auth.$name.com/saml/singleSignOn" />
   </IDPSSODescriptor>
@@ -914,18 +998,12 @@ oAqDknbUxfFTntp0VkdKrB64xr0Stpy7123hPszat3SbU3RYypdobEcuSAS77w9X1KnkRL1+CIe5
     <SingleLogoutService Binding="urn:oasis:names:tc:SAML:2.0:bindings:$typeSLO"
      Location="http://auth.$name.com/saml/proxySingleLogout"
     ResponseLocation="http://auth.$name.com/saml/proxySingleLogoutReturn" />
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
     <AssertionConsumerService isDefault="true" index="0"
      Binding="urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST"
      Location="http://auth.$name.com/saml/proxySingleSignOnPost" />
@@ -969,18 +1047,12 @@ oAqDknbUxfFTntp0VkdKrB64xr0Stpy7123hPszat3SbU3RYypdobEcuSAS77w9X1KnkRL1+CIe5
     </KeyDescriptor>
     <AttributeService Binding="urn:oasis:names:tc:SAML:2.0:bindings:SOAP"
      Location="http://auth.$name.com/saml/AA/SOAP" />
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
   </AttributeAuthorityDescriptor>
   <Organization>
     <OrganizationName xml:lang="en">$org</OrganizationName>
@@ -1042,18 +1114,12 @@ entityID="http://auth.$name.com/saml/metadata">
     <SingleLogoutService Binding="urn:oasis:names:tc:SAML:2.0:bindings:$type"
      Location="http://auth.$name.com/saml/singleLogout"
     ResponseLocation="http://auth.$name.com/saml/singleLogoutReturn" />
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
     <SingleSignOnService Binding="urn:oasis:names:tc:SAML:2.0:bindings:$type"
      Location="http://auth.$name.com/saml/singleSignOn" />
   </IDPSSODescriptor>
@@ -1097,18 +1163,12 @@ entityID="http://auth.$name.com/saml/metadata">
     <SingleLogoutService Binding="urn:oasis:names:tc:SAML:2.0:bindings:$type"
      Location="http://auth.$name.com/saml/proxySingleLogout"
     ResponseLocation="http://auth.$name.com/saml/proxySingleLogoutReturn" />
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
     <AssertionConsumerService isDefault="true" index="0"
      Binding="urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST"
      Location="http://auth.$name.com/saml/proxySingleSignOnPost" />
@@ -1150,18 +1210,12 @@ entityID="http://auth.$name.com/saml/metadata">
     </KeyDescriptor>
     <AttributeService Binding="urn:oasis:names:tc:SAML:2.0:bindings:SOAP"
      Location="http://auth.$name.com/saml/AA/SOAP" />
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
   </AttributeAuthorityDescriptor>
   <Organization>
     <OrganizationName xml:lang="en">$org</OrganizationName>
@@ -1223,18 +1277,12 @@ entityID="http://auth.$name.com/saml/metadata">
     <SingleLogoutService Binding="urn:oasis:names:tc:SAML:2.0:bindings:$typeSLO"
      Location="http://auth.$name.com/saml/singleLogout"
     ResponseLocation="http://auth.$name.com/saml/singleLogoutReturn" />
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
     <SingleSignOnService Binding="urn:oasis:names:tc:SAML:2.0:bindings:$typeSSO"
      Location="http://auth.$name.com/saml/singleSignOn" />
   </IDPSSODescriptor>
@@ -1278,18 +1326,12 @@ entityID="http://auth.$name.com/saml/metadata">
     <SingleLogoutService Binding="urn:oasis:names:tc:SAML:2.0:bindings:$typeSLO"
      Location="http://auth.$name.com/saml/proxySingleLogout"
     ResponseLocation="http://auth.$name.com/saml/proxySingleLogoutReturn" />
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
     <AssertionConsumerService isDefault="true" index="0"
      Binding="urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST"
      Location="http://auth.$name.com/saml/proxySingleSignOnPost" />
@@ -1331,18 +1373,12 @@ entityID="http://auth.$name.com/saml/metadata">
     </KeyDescriptor>
     <AttributeService Binding="urn:oasis:names:tc:SAML:2.0:bindings:SOAP"
      Location="http://auth.$name.com/saml/AA/SOAP" />
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
-    <NameIDFormat>
-    urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
+    <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
   </AttributeAuthorityDescriptor>
   <Organization>
     <OrganizationName xml:lang="en">$org</OrganizationName>
@@ -1362,16 +1398,22 @@ Match a XPath expression against the provided string, and verify that the correc
 
 =cut
 
-sub expectXPath {
+sub getXPath {
     local $Test::Builder::Level = $Test::Builder::Level + 1;
-    my ( $xml_string, $xpath, $value, $message ) = @_;
-    my $dom = XML::LibXML->load_xml( string => $xml_string );
+    my ( $string_or_dom, $xpath ) = @_;
+
+    my $dom =
+      ref($string_or_dom)
+      ? $string_or_dom
+      : XML::LibXML->load_xml( string => $string_or_dom );
     return unless ok( $dom, 'XML successfully parsed' );
 
     my $xpc        = XML::LibXML::XPathContext->new($dom);
     my $namespaces = {
         samlp => 'urn:oasis:names:tc:SAML:2.0:protocol',
         saml  => 'urn:oasis:names:tc:SAML:2.0:assertion',
+        md    => 'urn:oasis:names:tc:SAML:2.0:metadata',
+        sig   => 'http://www.w3.org/2000/09/xmldsig#',
     };
     if ( ref($namespaces) eq "HASH" ) {
         for my $key ( keys %{$namespaces} ) {
@@ -1379,7 +1421,14 @@ sub expectXPath {
         }
     }
 
-    my ($match1) = $xpc->findnodes($xpath);
+    return $xpc->findnodes($xpath);
+}
+
+sub expectXPath {
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+    my ( $xml_string, $xpath, $value, $message ) = @_;
+
+    my ($match1) = getXPath( $xml_string, $xpath );
     return unless ok( $match1, 'Found a match for XPath Expression ' . $xpath );
 
     if ( ref($match1) eq 'XML::LibXML::Attr' ) {
@@ -1415,4 +1464,43 @@ sub expectSamlResponse {
     return decode_base64( uri_unescape($sr) );
 }
 
+sub normalizeX509Data {
+    my ($data) = @_;
+
+    # Remove heading lines
+    $data =~ s/^---.*---$//mg;
+
+    # Remove heading/trailing ws
+    $data =~ s/(?:^\s+|\s+$)//g;
+
+    return $data;
+}
+
+sub expectMetadataCerts {
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+    my ( $doc, $expected_signing_keys, $expected_encryption_keys ) = @_;
+
+    my @signing_keys = map { $_->data } getXPath(
+        $doc,
+'(//md:IDPSSODescriptor | //md:SPSSODescriptor)[1]/md:KeyDescriptor[@use="signing"]/sig:KeyInfo/sig:X509Data/sig:X509Certificate/text()',
+    );
+
+    is_deeply(
+        [ map { normalizeX509Data($_) } @signing_keys ],
+        [ map { normalizeX509Data($_) } @$expected_signing_keys ],
+        "Offered signing certs match excepted ones"
+    );
+
+    my @encryption_keys = map { $_->data } getXPath(
+        $doc,
+'(//md:IDPSSODescriptor | //md:SPSSODescriptor)[1]/md:KeyDescriptor[@use="encryption"]/sig:KeyInfo/sig:X509Data/sig:X509Certificate/text()',
+    );
+
+    is_deeply(
+        [ map { normalizeX509Data($_) } @encryption_keys ],
+        [ map { normalizeX509Data($_) } @$expected_encryption_keys ],
+        "Offered encryption certs match excepted ones"
+    );
+    count(2);
+}
 1;
